@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.25";
+our $VERSION = "2.26";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
@@ -267,6 +267,14 @@ sub pop_reset {
 
 use constant MAX_INT => ~0 >> 1;
 
+sub IsEOL {
+    <<"END";
+0000\t0000
+000A\t000D
+2028\t2029
+END
+}
+
 sub fold {
     my $obj = shift;
     local $_ = shift // '';
@@ -279,7 +287,8 @@ sub fold {
     my $width = $opt->{width};
     looks_like_number $width and $width == int($width)
 	or croak "$width: invalid width";
-    $width = MAX_INT if $width < 0;
+    $opt->{padding} = 0 if $width <= 0;
+    $width = MAX_INT    if $width <  0;
     ($width -= $opt->{margin}) > 0 or croak "margin too big";
 
     my $word_char_re =
@@ -293,16 +302,16 @@ sub fold {
     my $room = $width;
     @bg_stack = @color_stack = @reset = ();
     my $unremarkable_re =
-	$opt->{expand} ? qr/[^\e\n\f\r\0\N{U+2028}\N{U+2029}\t]/
-		       : qr/[^\e\n\f\r\0\N{U+2028}\N{U+2029}]/;
+	$opt->{expand} ? qr/[^\p{IsEOL}\e\t]/
+		       : qr/[^\p{IsEOL}\e]/;
 
   FOLD:
     while (length) {
 
-	# newline, null
+	# newline, null, vt
 	# U+2028: Line Separator
 	# U+2029: Paragraph Separator
-	if (s/\A(\r*\n|[\0\N{U+2028}\N{U+2029}])//) {
+	if (s/\A(\r*\n|[\0\x0b\N{U+2028}\N{U+2029}])//) {
 	    $eol = $1;
 	    last;
 	}
@@ -569,7 +578,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.25
+Version 2.26
 
 =head1 SYNOPSIS
 
